==> edit-json-file-1.4.1.tgz: edit-json-file/README.md <==
# Installation
> `npm install --save @types/edit-json-file`

# Summary
This package contains type definitions for edit-json-file (https://github.com/IonicaBizau/edit-json-file#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file/index.d.ts)
````ts
// Type definitions for edit-json-file 1.4
// Project: https://github.com/IonicaBizau/edit-json-file#readme
// Definitions by: Twixes <https://github.com/Twixes>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types= "node" />

import { NoParamCallback } from 'fs';

declare namespace editJsonFile {
    /** JSON file editor options. */
    interface Options {
        stringify_width?: number | undefined;
        stringify_fn?: ((data: object) => string) | undefined;
        stringify_eol?: boolean | undefined;
        autosave?: boolean | undefined;
    }

    /** JSON file editor. */
    interface JsonEditor {
        /** Get value at path. */
        get(path?: string): any;
        /** Set value at path. */
        set(path: string, value: any): JsonEditor;
        /** Unset value at path. */
        unset(path: string): JsonEditor;
        /** Read the JSON file. */
        read(cb?: NoParamCallback): object;
        /** Overwrite the JSON file. */
        write(content: string, cb?: NoParamCallback): JsonEditor;
        /** Empty the JSON file. */
        empty(cb?: NoParamCallback): JsonEditor;
        /** Save the JSON file back to disk. */
        save(cb?: NoParamCallback): JsonEditor;
        /** Get full object. */
        toObject(): object;
    }
}

/** Create a JSON file editor. */
declare function editJsonFile(path: string, options?: editJsonFile.Options): editJsonFile.JsonEditor;

export = editJsonFile;

````

### Additional Details
 * Last updated: Thu, 08 Jul 2021 12:01:03 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [Twixes](https://github.com/Twixes).

==> edit-json-file-1.6.0.tgz: edit-json-file/README.md <==
# Installation
> `npm install --save @types/edit-json-file`

# Summary
This package contains type definitions for edit-json-file (https://github.com/IonicaBizau/edit-json-file#readme).

# Details
Files were exported from https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file.
## [index.d.ts](https://github.com/DefinitelyTyped/DefinitelyTyped/tree/master/types/edit-json-file/index.d.ts)
````ts
// Type definitions for edit-json-file 1.6
// Project: https://github.com/IonicaBizau/edit-json-file#readme
// Definitions by: Twixes <https://github.com/Twixes>
// Definitions: https://github.com/DefinitelyTyped/DefinitelyTyped

/// <reference types= "node" />

import { NoParamCallback } from 'fs';

declare namespace editJsonFile {
    /** JSON file editor options. */
    interface Options {
        stringify_width?: number | undefined;
        stringify_fn?: ((data: object) => string) | undefined;
        stringify_eol?: boolean | undefined;
        autosave?: boolean | undefined;
    }

    /** JSON file editor. */
    interface JsonEditor {
        /** Get value at path. */
        get(path?: string): any;
        /** Set value at path. */
        set(path: string, value: any): JsonEditor;
        /** Appends a value/object to a specific path. */
        append(path: string, value: any): JsonEditor;
        /** Pop an array from a specific path. */
        pop(path: string): JsonEditor;
        /** Unset value at path. */
        unset(path: string): JsonEditor;
        /** Read the JSON file. */
        read(cb?: NoParamCallback): object;
        /** Overwrite the JSON file. */
        write(content: string, cb?: NoParamCallback): JsonEditor;
        /** Empty the JSON file. */
        empty(cb?: NoParamCallback): JsonEditor;
        /** Save the JSON file back to disk. */
        save(cb?: NoParamCallback): JsonEditor;
        /** Get full object. */
        toObject(): object;
    }
}

/** Create a JSON file editor. */
declare function editJsonFile(path: string, options?: editJsonFile.Options): editJsonFile.JsonEditor;

export = editJsonFile;

````

### Additional Details
 * Last updated: Wed, 18 Aug 2021 20:31:24 GMT
 * Dependencies: [@types/node](https://npmjs.com/package/@types/node)
 * Global values: none

# Credits
These definitions were written by [Twixes](https://github.com/Twixes).
